@@ -12,6 +12,8 @@ __all__ = ['ReturnValue', 'run']
 
 vd.curses_timeout = 100 # curses timeout in ms
 vd.timeouts_before_idle = 10
+vd.min_draw_ms = 100  # draw_all at least this often, even if keystrokes are pending
+vd._lastDrawTime = 0  # last time drawn (from time.time())
 
 vd.option('disp_splitwin_pct', 0, 'height of second sheet on screen')
 vd.option('mouse_interval', 1, 'max time between press/release for click (ms)', sheettype=None)
@@ -44,9 +46,14 @@ def draw_sheet(self, scr, sheet):
         self.exceptionCaught(e)
 
     try:
-        vd.drawSidebar(scr, sheet.sidebar)
+        sidebar = sheet.sidebar
+        sidebar_title = sheet.sidebar_title
     except Exception as e:
         vd.exceptionCaught(e)
+        sidebar = str(e)
+        sidebar_title = 'error'
+
+    vd.drawSidebar(scr, sidebar, title=sidebar_title)
 
 
 def iterwraplines(lines, width=80):
@@ -230,7 +237,9 @@ def mainloop(self, scr):
 
         vd.setWindows(vd.scrFull)
 
-        self.draw_all()
+        if not self.drainPendingKeys(scr) or time.time() - self._lastDrawTime > self.min_draw_ms/1000:  #1459
+            self.draw_all()
+            self._lastDrawTime = time.time()
 
         if vd._nextCommands:
             sheet.execCommand(vd._nextCommands.pop(0), keystrokes=self.keystrokes)
@@ -373,4 +382,4 @@ def run(vd, *sheetlist):
     vd.cancelThread(*[t for t in vd.unfinishedThreads if not t.name.startswith('save_')])
 
     if ret:
-        print(ret)
+        vd.printout(ret)
